@@ -1,5 +1,6 @@
 /* read-packet.c - Read OpenPGP packets
- * Copyright (C) 2001, 2002, 2003, 2007, 2008 Free Software Foundation, Inc.
+ * Copyright (C) 2001, 2002, 2003, 2007, 2008, 2010 Free Software
+ * Foundation, Inc.
  *
  * Author: Timo Schulz
  *
@@ -360,8 +361,7 @@ read_secret_key (cdk_stream_t inp, size_t pktlen, cdk_pkt_seckey_t sk)
 	sk->protect.ivlen = 0;
       else
 	{
-	  sk->protect.ivlen =
-	    _gnutls_cipher_get_block_size (sk->protect.algo);
+	  sk->protect.ivlen = gnutls_cipher_get_block_size (sk->protect.algo);
 	  if (!sk->protect.ivlen)
 	    return CDK_Inv_Packet;
 	  rc = stream_read (inp, sk->protect.iv, sk->protect.ivlen, &nread);
