@@ -1,5 +1,6 @@
 /* sig-check.c - Check signatures
- * Copyright (C) 1998-2002, 2003, 2007, 2008 Free Software Foundation, Inc.
+ * Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2007, 2008, 2010
+ * Free Software Foundation, Inc.
  *
  * Author: Timo Schulz
  *
@@ -288,7 +289,8 @@ _cdk_pk_check_sig (cdk_keydb_hd_t keydb,
 
   if (is_selfsig)
     *is_selfsig = 0;
-  if (knode->pkt->pkttype != CDK_PKT_PUBLIC_KEY ||
+  if ((knode->pkt->pkttype != CDK_PKT_PUBLIC_KEY &&
+       knode->pkt->pkttype != CDK_PKT_PUBLIC_SUBKEY) ||
       snode->pkt->pkttype != CDK_PKT_SIGNATURE)
     {
       gnutls_assert ();
@@ -549,7 +551,7 @@ cdk_pk_check_sigs (cdk_kbnode_t key, cdk_keydb_hd_t keydb, int *r_status)
 	{
 	  /* add every uid in the uid list. Only consider valid:
 	   * - verification was ok
-	   * - not a selfsig 
+	   * - not a selfsig
 	   */
 	  rc =
 	    uid_list_add_sig (&uid_list, uid_name,
@@ -579,7 +581,7 @@ exit:
  * cdk_pk_check_self_sig:
  * @key: the key node
  * @r_status: output the status of the key.
- * 
+ *
  * A convenient function to make sure the key is valid.
  * Valid means the self signature is ok.
  **/
@@ -591,45 +593,56 @@ cdk_pk_check_self_sig (cdk_kbnode_t key, int *r_status)
   cdk_error_t rc;
   u32 keyid[2], sigid[2];
   int is_selfsig, sig_ok;
+  cdk_kbnode_t p, ctx = NULL;
+  cdk_packet_t pkt;
 
   if (!key || !r_status)
     return CDK_Inv_Value;
 
-  node = cdk_kbnode_find (key, CDK_PKT_PUBLIC_KEY);
-  if (!node)
-    return CDK_Error_No_Key;
-  /* FIXME: we should set expire/revoke here also but callers
-     expect CDK_KEY_VALID=0 if the key is okay. */
   cdk_pk_get_keyid (key->pkt->pkt.public_key, keyid);
-  sig_ok = 0;
-  for (node = key; node; node = node->next)
+
+  while ((p = cdk_kbnode_walk (key, &ctx, 0)))
     {
-      if (node->pkt->pkttype != CDK_PKT_SIGNATURE)
+      pkt = cdk_kbnode_get_packet (p);
+      if (pkt->pkttype != CDK_PKT_PUBLIC_SUBKEY
+	  && pkt->pkttype != CDK_PKT_PUBLIC_KEY)
 	continue;
-      sig = node->pkt->pkt.signature;
-      if (!IS_UID_SIG (sig))
-	continue;
-      cdk_sig_get_keyid (sig, sigid);
-      if (sigid[0] != keyid[0] || sigid[1] != keyid[1])
-	continue;
-      /* FIXME: Now we check all self signatures. */
-      rc = _cdk_pk_check_sig (NULL, key, node, &is_selfsig, NULL);
-      if (rc)
+
+      /* FIXME: we should set expire/revoke here also but callers
+         expect CDK_KEY_VALID=0 if the key is okay. */
+      sig_ok = 0;
+      for (node = p; node; node = node->next)
+	{
+	  if (node->pkt->pkttype != CDK_PKT_SIGNATURE)
+	    continue;
+	  sig = node->pkt->pkt.signature;
+
+	  cdk_sig_get_keyid (sig, sigid);
+	  if (sigid[0] != keyid[0] || sigid[1] != keyid[1])
+	    continue;
+	  /* FIXME: Now we check all self signatures. */
+	  rc = _cdk_pk_check_sig (NULL, p, node, &is_selfsig, NULL);
+	  if (rc)
+	    {
+	      *r_status = CDK_KEY_INVALID;
+	      return rc;
+	    }
+	  else			/* For each valid self sig we increase this counter. */
+	    sig_ok++;
+	}
+
+      /* A key without a self signature is not valid. At least one
+       * signature for the given key has to be found.
+       */
+      if (!sig_ok)
 	{
 	  *r_status = CDK_KEY_INVALID;
-	  return rc;
+	  return CDK_General_Error;
 	}
-      else			/* For each valid self sig we increase this counter. */
-	sig_ok++;
     }
 
-  /* A key without a self signature is not valid. */
-  if (!sig_ok)
-    {
-      *r_status = CDK_KEY_INVALID;
-      return CDK_General_Error;
-    }
   /* No flags indicate a valid key. */
   *r_status = CDK_KEY_VALID;
+
   return 0;
 }
