@@ -210,6 +210,10 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "X520postalAddress", 1073741826, "PostalAddress"},
   { "PostalAddress", 1610612747, NULL },
   { NULL, 2, "DirectoryString"},
+  { "id-at-postalCode", 1880096780, "AttributeType"},
+  { NULL, 1073741825, "id-at"},
+  { NULL, 1, "17"},
+  { "X520postalCode", 1073741826, "DirectoryString"},
   { "emailAddress", 1880096780, "AttributeType"},
   { "iso", 1073741825, "1"},
   { "member-body", 1073741825, "2"},
